## Glyphs

Glyphs 3 is a professional Mac application for creating OpenType fonts.
It allows you to draw, edit and test letterforms in the context of words, and helps you manage all aspects of modern font production, including the efficient reuse of recurring shapes and the creation of large font families.
You can extend the functionality of Glyphs with plug-ins and Python scripts, many of which are freely available and accessible from within the application.

### Glyphs Mini

As an alternative to the pro version, there is a slimmed-down and more affordable version of the application called Glyphs Mini.
It lacks some features of the pro app, notably interpolation and extensibility, and has a narrower range of export formats.
The Glyphs Mini handbook is available at https://glyphsapp.com/learn.

### Community

Glyphs is also a vibrant community.
On our website you will find many ways to get involved.
We encourage you to use the Forum to ask questions and discuss issues with other users and the developers.
The Learn section has a large collection of tutorials, screencasts, online classes and other educational material.
Keep an eye out for workshops, conferences, and the latest updates in the News section.
If you are planning a workshop, organizing a Glyphs-related event, or releasing a plug-in you have developed, we will be happy to share your contribution on https://glyphsapp.com.

### Issues

If the application crashes, submitting the crash report dialog that appears the next time you launch the application will help us troubleshoot the problem that caused the crash.
If you can, please describe steps for reliably reproducing the issue in the forum.
The most likely cause of a crash is an incorrect interaction with a plug-in.
You can disable plug-ins by holding down the Option and Shift keys when the application starts.

An issue you encounter may have been fixed in the latest beta version of the application.
See Updates for details.